@@ -12,13 +12,15 @@ class SQSClient(Boto3Client):
         super().__init__('sqs')
 
     def send_preprocess_job(self,
-                            project_id: int,
-                            document_id: int):
+                            bucket: str,
+                            document: dict,
+                            pages: list):
         """
         """
         msg_body = {
-            'projectId': project_id,
-            'documentId': document_id
+            'bucket': bucket,
+            'document': json.dumps(document),
+            'pages': json.dumps(pages)
         }
         self.send_message(
             QueueUrl="https://sqs.eu-west-3.amazonaws.com/749868801319/preprocess-queue",
@@ -26,12 +28,14 @@ class SQSClient(Boto3Client):
         )
         
     def send_ocr_job(self,
-                     project_id: int,
+                     bucket: str,
+                     img_uri: str,
                      page_id: int):
         """
         """
         msg_body = {
-            'projectId': project_id,
+            'bucket': bucket,
+            'imgUri': img_uri,
             'pageId': page_id
         }
         self.send_message(
